######################################################
#' @title Figure 1 - Boxplot of top ten ranked pathwasy
#' @author A. Grant Schissler
#' @date 2 Dec 2015
#' @description XXX
######################################################

######################################################
## Create figure 1 based on the top 5 clustered bootstrap pathways

setwd("./Figure3")
rm(list=ls())

## load in pre-computed MD scores for all pairs
load("../CommonData/CTC_tumor_resample.RData")

### lab colors:
purple <- "#A078AA"
orange <- "#FFA040"
green <- "#72BF44"
grey <- "#777676"
yellow <- "#F9F080"

## explore top hits under nominal p-value 0.05
str(top.boot)
str(top.data)

## keep the top 5 pathways for Figure 1
top.boot <- top.boot[1:5]
top.labels <- c("ncWnt","ErbB2/B3","SDC4", "FOXM1", "S1P1")[5:1] ## reverse order here as the scales are reversed later

## retrieve MD scores for all B-A pairs
b.a.matrix <- md.matrix[b.a.index,]

## wide to long format for plotting
require(reshape2)
top.md.data <- data.frame(b.a.matrix[,names(top.boot)])
names(top.md.data) <- gsub("^X","",names(top.md.data))
top.md.long <- melt(top.md.data)
names(top.md.long) <- c("PID.ID","MD.Score")
levels(top.md.long$PID.ID) <- rev(top.labels)

## give full description of pathways
## top.md.long$Desc <- factor(top.md.long$PID.ID, labels=paste0(pid.data[names(top.boot),"description"]))

##### create boxplot visualization
### hide outliers
p0 <- ggplot(data = top.md.long, aes(y = MD.Score)) + geom_boxplot(aes(x = PID.ID, fill= PID.ID), outlier.colour = rgb(0,0,0,alpha = 0))

## from Ramnath: http://stackoverflow.com/questions/5677885/ignore-outliers-in-ggplot2-boxplot
## compute lower and upper whiskers
## length(boxplot.stats(top.md.long$MD.Score)$out)/nrow(top.md.long) ## 862/7380 points are outlying

ylim1 <- boxplot.stats(top.md.long$MD.Score)$stats[c(1, 5)]
ylim1 <- ylim1 + c(-0.05, 0.05) * diff(ylim1) / 2

## scale y limits based on ylim1
scale.factor <- 1.5
p1 <- p0 + coord_flip(ylim = c(ylim1[1],ylim1[2]*scale.factor))

### add scales and titles
## polish via code from Jaap: http://stackoverflow.com/questions/23635662/editing-legend-text-labels-in-ggplot
p2 <- p1 +
    labs(title="Top 5 Pathways Ranked by MD B-A Pairs\n", x="Pathway Interaction Database ID", y="MD Score") +
    scale_fill_manual("",labels = pid.data[names(top.boot),"description"],
                       values = c(purple,orange,green,grey,yellow)) + theme_bw()

## add line of non-dysregulation
p3 <- p2 + geom_hline(h=0, col="red", linetype = 1, size = 0.5) + guides(fill = guide_legend(reverse = TRUE))

## more legend
(p4 <- p3 + theme(legend.position = "bottom", legend.direction = "vertical"))

pdf("Figure3.pdf", width=6.69291) ## 6.69291 inches ~ 170 mm
p4
dev.off()
